==> calligra_3.0.1.orig.tar.xz: calligra-3.0.1/sheets/part/dialogs/PageLayoutDialog.h <==
/* This file is part of the KDE project
   Copyright 2008 Stefan Nikolaus <stefan.nikolaus@kdemail.net>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef CALLIGRA_SHEETS_PAGE_LAYOUT_DIALOG
#define CALLIGRA_SHEETS_PAGE_LAYOUT_DIALOG

#include <KoPageLayoutDialog.h>

namespace Calligra
{
namespace Sheets
{
class Sheet;

/**
 * \ingroup UI
 * Dialog to set the page layout.
 */
class PageLayoutDialog : public KoPageLayoutDialog
{
    Q_OBJECT
public:
    /**
     * Constructor.
     */
    explicit PageLayoutDialog(QWidget* parent, Sheet* sheet);

    /**
     * Destructor.
     */
    virtual ~PageLayoutDialog();

public Q_SLOTS:
    virtual void accept();

private:
    class Private;
    Private * const d;
};

} // namespace Sheets
} // namespace Calligra

#endif // CALLIGRA_SHEETS_PAGE_LAYOUT_DIALOG

==> calligra-3.2.1.tar.xz: calligra-3.2.1/sheets/part/dialogs/PageLayoutDialog.h <==
/* This file is part of the KDE project
   Copyright 2008 Stefan Nikolaus <stefan.nikolaus@kdemail.net>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef CALLIGRA_SHEETS_PAGE_LAYOUT_DIALOG
#define CALLIGRA_SHEETS_PAGE_LAYOUT_DIALOG

#include <KoPageLayoutDialog.h>

namespace Calligra
{
namespace Sheets
{
class Sheet;

/**
 * \ingroup UI
 * Dialog to set the page layout.
 */
class PageLayoutDialog : public KoPageLayoutDialog
{
    Q_OBJECT
public:
    /**
     * Constructor.
     */
    explicit PageLayoutDialog(QWidget* parent, Sheet* sheet);

    /**
     * Destructor.
     */
    ~PageLayoutDialog() override;

public Q_SLOTS:
    void accept() override;

private:
    class Private;
    Private * const d;
};

} // namespace Sheets
} // namespace Calligra

#endif // CALLIGRA_SHEETS_PAGE_LAYOUT_DIALOG
